
*##############################################################################################*
*                     #################################################                        *
*                     #  NATIONAL ELECTIONS - REGIONAL LEVEL RESULTS  #                        *
*                     #################################################                        *
*##############################################################################################*

use "D:\Book Analysis II\QAIIb.Jan08.new.dta"


********************************************************************************
*                         DEFINITION OF VARIABLES					 *
********************************************************************************
*  autonomy = region have decision-making autonomy                             *
*  autoIndex = index of regional autonomy                                      *
*  gain = region gained autonomy (coded as gain in only years regions have     * 
*     autonomy) *                                                              *
*  gain2 = region gained autonomy (includes UTs in India that become states    *
*  loss = loss autonomy                                                        *
*  change in autonomy (gain2 + loss)                                           *
*  dcen = dichotomous measure of decentralization (natl level)		       *
*  dcenIndex = index of decentralization	(natl level)		             *
*  furpVOTE = regional party vote (% of total vote)                            *
*  furpSEAT = regional party vote (% of total seats)                           *
*  furpNUMBER = regional parties (% of all parties)                            *
*    regions are defined as adminstrative divisions in this file.	             *
*  EXPshare05 = subnational expenditure (% of total expenditure)               *
*  EXPgdp05 = subnational expenditure (% of gdp)           			       *
*  REVgdp05 = subnational expenditure (% of gdp)                               *
*  mixed = mixed electoral system							       *
*  majplr = majority and plurality systems				             *
*  age = age of democracy				                               *
*  elect = election year                                                       *
*  felect = election year of first democratic elections                        *
*  felect2 = felect + 3 elections after periods where polity 5 fell below 5    *
*  prz = presidentialism								       *	
*  przcon = concurrent presidential and legislative elections		       *
*  przncon = nonconcurrent presidential and legislative elections	             *
*  rbase = % of pop (all groups over 1%) that has a regional base.           	 *
*  elf = ethnolinguistic fractionalization (elf) index.	 		       *
*  noncontig = country whose territory is noncontiguous			       *
*  UKcolony = former colony of the United Kingdom				       *
********************************************************************************


*****************************************************
*Notes:                                             *
(1) Colombia is excluded from models including frm. *
(2) All models restricted to the same population.   *
*****************************************************

**((CHAPTER MODELS))**

*AUTONOMY WITH CNTY FIXED EFFECTS*
xi: reg furpNUMBER autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
  outreg autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpVOTE autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
  outreg autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpSEAT autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
  outreg autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

*AUTONOMY INDEX WITH CNTY FIXED EFFECTS*
xi: reg furpNUMBER auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpVOTE auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpSEAT auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg auto5ptIndex rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Table 7.1 National Elections - Regional Level Results) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)


**((APPENDIX MODELS))**

*AUTONOMY WITH CNTY FIXED EFFECTS W/OUT INDIA TO DETERMINE AFFECT ON FRM(CNTY THAT CHANGED BORDERS)*
xi: reg furpNUMBER autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if cnty != "India" & furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT3, replace se 3aster coefastr bdec(2) rdec(3) title (Models without India) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpVOTE autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if cnty != "India" & furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT3, append replace se 3aster coefastr bdec(2) rdec(3) title (Models without India) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpSEAT autonomy rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if cnty != "India" & furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT3, append replace se 3aster coefastr bdec(2) rdec(3) title (Models without India) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)


**GAINS/LOSES TO AUTONOMY*
xi: reg furpVOTE autonomy gain rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
xi: reg furpVOTE autonomy gain2 rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy gain2 rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT1, replace se 3aster coefastr bdec(2) rdec(3) title (Change in Autonomy) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
*xi: reg furpNUMBER autonomy gain2 rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
*xi: reg furpSEAT autonomy gain2 rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
xi: reg furpVOTE autonomy loss rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy loss rbase frm prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT1, append replace se 3aster coefastr bdec(2) rdec(3) title (Change in Autonomy) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
*xi: reg furpNUMBER autonomy loss rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
*xi: reg furpSEAT autonomy loss rbase frm prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust


**AUTONOMY WITH SES CLUSTERED BY COUNTRIES*
reg furpNUMBER autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(cnty)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(cnty)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpSEAT autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster (cnty)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpNUMBER auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(cnty)
   outreg auto5ptIndex  frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(cnty)
   outreg auto5ptIndex  frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpSEAT auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster (cnty)
   outreg auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with Clustered SEs) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

*AUTONOMY WITH CNTY FIXED EFFECTS w/FRM SO THAT COLOMBIA IS INCLUDED*
xi: reg furpNUMBER autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT4, replace se 3aster coefastr bdec(2) rdec(3) title (Models without Regional Size [Colombia Included]) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpVOTE autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT4, append replace se 3aster coefastr bdec(2) rdec(3) title (Models without Regional Size [Colombia Included]) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
xi: reg furpSEAT autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts i.cnty if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., robust
   outreg autonomy rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT4, append replace se 3aster coefastr bdec(2) rdec(3) title (Models without Regional Size [Colombia Included]) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)

*AUTONOMY WITH SES CLUSTERED BY REGIONS*
reg furpNUMBER autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(admdivision)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT5, replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(admdivision)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT5, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpSEAT autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster (admdivision)
   outreg autonomy frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT5, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpNUMBER auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(admdivision)
   outreg auto5ptIndex  frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpVOTE auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster(admdivision)
   outreg auto5ptIndex  frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)
reg furpSEAT auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw forties fifties sixties seventies eighties nineties naughts if furpNUMBER!=. & furpVOTE != . & furpSEAT !=., cluster (admdivision)
   outreg auto5ptIndex frm rbase prznoncon przcon mixed majplr age tnre Xlaw using Book_Appendix_QAIIbT2, append replace se 3aster coefastr bdec(2) rdec(3) title (Models with SEs Clustered by Administrative Division) nonotes addnote(Decade-fixed effects not shown. Standard errors in parentheses.  *p=0.10, **p=0.05, ***p=0.01.)


